==> qtvirtualkeyboard-opensource-src_5.12.8+dfsg.orig.tar.xz: qtvirtualkeyboard-everywhere-src-5.12.8/src/plugins/tcime/plugin/tcimeplugin.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Virtual Keyboard module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef TCIMEPLUGIN_H
#define TCIMEPLUGIN_H

#include <QVirtualKeyboardExtensionPlugin>

QT_BEGIN_NAMESPACE

class QtVirtualKeyboardTCImePlugin : public QVirtualKeyboardExtensionPlugin
{
    Q_OBJECT
    Q_INTERFACES(QVirtualKeyboardExtensionPlugin)
    Q_PLUGIN_METADATA(IID QVirtualKeyboardExtensionPluginFactoryInterface_iid
                      FILE "tcime.json")
public:
    void registerTypes(const char *uri) const;
};

QT_END_NAMESPACE

#endif

==> qtvirtualkeyboard-opensource-src_5.15.17+dfsg.orig.tar.xz: qtvirtualkeyboard-everywhere-src-5.15.17/src/plugins/tcime/plugin/tcimeplugin.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Virtual Keyboard module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef TCIMEPLUGIN_H
#define TCIMEPLUGIN_H

#include <QVirtualKeyboardExtensionPlugin>

QT_BEGIN_NAMESPACE

class QtVirtualKeyboardTCImePlugin : public QVirtualKeyboardExtensionPlugin
{
    Q_OBJECT
    Q_INTERFACES(QVirtualKeyboardExtensionPlugin)
    Q_PLUGIN_METADATA(IID QVirtualKeyboardExtensionPluginFactoryInterface_iid
                      FILE "tcime.json")
public:
    void registerTypes(const char *uri) const override;
};

QT_END_NAMESPACE

#endif
